@@ -14,11 +14,21 @@ DLLEXPORT int ReturnInt()
     return 101;
 }
 
+DLLEXPORT int ReturnNegInt()
+{
+    return -101;
+}
+
 DLLEXPORT short ReturnShort()
 {
     return 102;
 }
 
+DLLEXPORT short ReturnNegShort()
+{
+    return -102;
+}
+
 DLLEXPORT signed char ReturnByte()
 {
     return -103;
@@ -49,6 +59,11 @@ DLLEXPORT int64_t ReturnInt64()
     return 0xFFFFFFFFFF;
 }
 
+DLLEXPORT int64_t ReturnNegInt64()
+{
+    return -0xFFFFFFFFFF;
+}
+
 DLLEXPORT unsigned char ReturnUint8()
 {
     return 0xFE;
