@@ -2,12 +2,19 @@
 #include <stdio.h>
 #include <stdbool.h>
 
+#ifdef _WIN32
+#define DLLEXPORT __declspec(dllexport)
+#else
+#define DLLEXPORT extern
+#endif
+
+
 typedef struct {
 	union {
 		int64_t x;
 	};
 } Outer;
 
-void prinx(Outer *out) {
+DLLEXPORT void prinx(Outer *out) {
 	printf("Have %lx\n", out->x);
 }
